@@ -31,6 +31,12 @@ pub struct ArrayString<A: Array<Item=u8>> {
     len: A::Index,
 }
 
+impl<A: Array<Item=u8>> Default for ArrayString<A> {
+    fn default() -> ArrayString<A> {
+        ArrayString::new()
+    }
+}
+
 impl<A: Array<Item=u8>> ArrayString<A> {
     /// Create a new empty `ArrayString`.
     ///
@@ -115,8 +121,6 @@ impl<A: Array<Item=u8>> ArrayString<A> {
 
     /// Adds the given char to the end of the string.
     ///
-    /// Returns `Ok` if the push succeeds.
-    ///
     /// ***Panics*** if the backing array is not large enough to fit the additional char.
     ///
     /// ```
@@ -166,8 +170,6 @@ impl<A: Array<Item=u8>> ArrayString<A> {
 
     /// Adds the given string slice to the end of the string.
     ///
-    /// Returns `Ok` if the push succeeds.
-    ///
     /// ***Panics*** if the backing array is not large enough to fit the string.
     ///
     /// ```
@@ -371,6 +373,7 @@ impl<A: Array<Item=u8>> Ord for ArrayString<A> {
 }
 
 #[cfg(feature="serde-1")]
+/// Requires crate feature `"serde-1"`
 impl<A: Array<Item=u8>> Serialize for ArrayString<A> {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
         where S: Serializer
@@ -380,6 +383,7 @@ impl<A: Array<Item=u8>> Serialize for ArrayString<A> {
 }
 
 #[cfg(feature="serde-1")]
+/// Requires crate feature `"serde-1"`
 impl<'de, A: Array<Item=u8>> Deserialize<'de> for ArrayString<A> {
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
         where D: Deserializer<'de>
